==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicCheckBoxMenuItemUI.h <==
// public class javax.swing.plaf.basic.BasicCheckBoxMenuItemUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5216db2ca259b37f javax_swing_plaf_ButtonUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 1c57b3e4816d873f javax_swing_plaf_MenuItemUI
// @dep_class 75b7bb84ca30d834 javax_swing_plaf_basic_BasicCheckBoxMenuItemUI
// @dep_class 13d878e926e1583d javax_swing_plaf_basic_BasicMenuItemUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicMenuItemUI

#include "javax/swing/plaf/basic/BasicMenuItemUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI_H_
#define _JC_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_JMenuItem$object;
struct _jc_javax_swing_MenuSelectionManager$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$installDefaults$4ef132a1c8be98a3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$processMouseEvent$c52f725aba7a5cc1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *, struct _jc_javax_swing_JMenuItem$object *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method_info$getPropertyPrefix$e7baa4035901c9a7;
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method_info$installDefaults$4ef132a1c8be98a3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method_info$processMouseEvent$c52f725aba7a5cc1;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *);
	void	(*installDefaults$4ef132a1c8be98a3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *);
	void	(*processMouseEvent$c52f725aba7a5cc1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *, struct _jc_javax_swing_JMenuItem$object *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ButtonUI$vmethods	javax_swing_plaf_ButtonUI;
	_jc_javax_swing_plaf_MenuItemUI$vmethods	javax_swing_plaf_MenuItemUI;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI$vmethods	javax_swing_plaf_basic_BasicMenuItemUI;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods	javax_swing_plaf_basic_BasicCheckBoxMenuItemUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs {
    _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs	javax_swing_plaf_basic_BasicCheckBoxMenuItemUI;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI$sub_refs	javax_swing_plaf_basic_BasicMenuItemUI;
    _jc_javax_swing_plaf_MenuItemUI$sub_refs	javax_swing_plaf_MenuItemUI;
    _jc_javax_swing_plaf_ButtonUI$sub_refs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ButtonUI$sub_nonrefs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs	javax_swing_plaf_MenuItemUI;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI$sub_nonrefs	javax_swing_plaf_basic_BasicMenuItemUI;
    _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs	javax_swing_plaf_basic_BasicCheckBoxMenuItemUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object {
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicCheckBoxMenuItemUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicCheckBoxMenuItemUI.h <==
// public class javax.swing.plaf.basic.BasicCheckBoxMenuItemUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5216db2ca259b37f javax_swing_plaf_ButtonUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 1c57b3e4816d873f javax_swing_plaf_MenuItemUI
// @dep_class 75b7bb84ca30d834 javax_swing_plaf_basic_BasicCheckBoxMenuItemUI
// @dep_class 82f7624f03bd0a6e javax_swing_plaf_basic_BasicMenuItemUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicMenuItemUI

#include "javax/swing/plaf/basic/BasicMenuItemUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI_H_
#define _JC_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_JMenuItem$object;
struct _jc_javax_swing_MenuSelectionManager$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$installDefaults$4ef132a1c8be98a3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$processMouseEvent$c52f725aba7a5cc1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *, struct _jc_javax_swing_JMenuItem$object *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method_info$getPropertyPrefix$e7baa4035901c9a7;
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method_info$installDefaults$4ef132a1c8be98a3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method_info$processMouseEvent$c52f725aba7a5cc1;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *) _JC_JCNI_ATTR;
	void	(*installDefaults$4ef132a1c8be98a3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *) _JC_JCNI_ATTR;
	void	(*processMouseEvent$c52f725aba7a5cc1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object *, struct _jc_javax_swing_JMenuItem$object *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ButtonUI$vmethods	javax_swing_plaf_ButtonUI;
	_jc_javax_swing_plaf_MenuItemUI$vmethods	javax_swing_plaf_MenuItemUI;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI$vmethods	javax_swing_plaf_basic_BasicMenuItemUI;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vmethods	javax_swing_plaf_basic_BasicCheckBoxMenuItemUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs {
    _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_refs	javax_swing_plaf_basic_BasicCheckBoxMenuItemUI;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI$sub_refs	javax_swing_plaf_basic_BasicMenuItemUI;
    _jc_javax_swing_plaf_MenuItemUI$sub_refs	javax_swing_plaf_MenuItemUI;
    _jc_javax_swing_plaf_ButtonUI$sub_refs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ButtonUI$sub_nonrefs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs	javax_swing_plaf_MenuItemUI;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI$sub_nonrefs	javax_swing_plaf_basic_BasicMenuItemUI;
    _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$sub_nonrefs	javax_swing_plaf_basic_BasicCheckBoxMenuItemUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$object {
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$vtype _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicCheckBoxMenuItemUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicCheckBoxMenuItemUI_H_ */
